@@ -156,8 +156,6 @@ class Context(object):
             self.log(arg_1, level, application_name=application_name,
                      process_stage=process_stage, **kwargs)
 
-    @staticmethod
-    def send_log_to_center(context, project="", module="", level=None, user=None, return_msg="", **kwargs):
-        return send_to_log_center(context, project=project, module=module, level=level,
-                                  user=user, return_msg=return_msg, **kwargs)
-
+    @property
+    def send_log_to_center(self):
+        return send_to_log_center
